@@ -1,16 +1,14 @@
 #
 # This file is part of MooseX-Attribute-Dependent
 #
-# This software is Copyright (c) 2011 by Moritz Onken.
+# This software is Copyright (c) 2016 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package MooseX::Attribute::Dependency;
-{
-  $MooseX::Attribute::Dependency::VERSION = '1.1.2';
-}
+$MooseX::Attribute::Dependency::VERSION = '1.1.3';
 use Moose;
 has [qw(parameters message constraint name)] => ( is => 'ro' );
 
@@ -42,11 +40,10 @@ sub register {
 __PACKAGE__->meta->make_immutable;
 
 package MooseX::Attribute::Dependencies;
-{
-  $MooseX::Attribute::Dependencies::VERSION = '1.1.2';
-}
+$MooseX::Attribute::Dependencies::VERSION = '1.1.3';
 use strict;
 use warnings;
+use List::MoreUtils ();
 
 MooseX::Attribute::Dependency::register(
     {   name       => 'All',
@@ -92,15 +89,18 @@ MooseX::Attribute::Dependency::register(
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::Attribute::Dependency
 
 =head1 VERSION
 
-version 1.1.2
+version 1.1.3
 
 =head1 AUTHOR
 
@@ -108,11 +108,10 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Moritz Onken.
+This software is Copyright (c) 2016 by Moritz Onken.
 
 This is free software, licensed under:
 
   The (three-clause) BSD License
 
 =cut
-
